#!C:\b\abs_46_z7gpsd2\croot\gdal-split_1691162709321\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.6.2','gdalattachpct.py'
__requires__ = 'GDAL==3.6.2'
__import__('pkg_resources').run_script('GDAL==3.6.2', 'gdalattachpct.py')
